from struct import pack, unpack, calcsize

# START:pack
def metaPack(format, data):

    # Length of metadata.
    result = pack("i", len(format))

    # Metadata.
    tmp = "%ds" % len(format)
    result += pack(tmp, format)

    # Records.
    for d in data:
        d = [format] + d
        result += pack(*d)

    # Done.
    return result
# END:pack

# START:unpack
def metaUnpack(data):

    # Length of metadata.
    intSize = calcsize("i")
    formatLen = unpack("i", data[0:intSize])[0]

    # Metadata.
    tmp = "%ds" % formatLen
    format = unpack(tmp, data[intSize:intSize+formatLen])[0]
    recordSize = calcsize(format)
    pos = intSize + formatLen

    # Records.
    result = []
    while pos < len(data):
        tmp = data[pos:pos+recordSize]
        d = unpack(format, tmp)
        result.append(list(d))
        pos += recordSize

    # Done.
    return result
# END:unpack

# START:test
if __name__ == "__main__":

    tests = [
        ["i",   [[1]]],
        ["i",   [[1], [2]]],

        ["3s",  [["xyz"]]],
        ["3s",  [["abc"], ["def"]]],

        ["f3s", [[1.0, "pqr"]]],
        ["f3s", [[2.0, "stu"], [3.0, "vwx"]]]
    ]

    for (format, original) in tests:
        tmp = metaPack(format, original)
        print repr(tmp)

        dup = metaUnpack(tmp)
        assert dup == original
# END:test
