import sys

def error(msg):
    print >> sys.stderr, msg
    sys.exit(1)

def readIni(inputName):
    input = open(inputName, 'r')
    result = []
    for line in input:
        line = line.strip()
        first = line.find('#')
        if first >= 0:
            line = line[:first]
        if (not line) or (line[0] == '#'):
            continue
        result.append(line)
    return result

def escape(s):
    return s.replace('&', '&amp;')\
           .replace('<', '&lt;')\
           .replace('>', '&gt;')\
           .replace("'", '&apos;')\
           .replace('"', '&quot;')

# START:process
def process(lines):
    result = []
    section = None
    content = {}
    for line in lines:

        # Start of new section
        if line[0] == '[':
            # Save old values (if any)
            if section:
                entry = [section, content]
                result.append(entry)

            # Start a new section
            section = line[1:-1]
            content = {}

        # Add to the current dictionary.
        else:
            key, value = line.split("=", 1)
            content[key] = escape(value)

    # Finish
    if section:
        entry = [section, content]
        result.append(entry)
    return result
# END:process

def translateName(inputName):
    return inputName[:-4] + '.xml'

# START:write
def writeXml(outputName, settings):
    output = open(outputName, 'w')
    print >> output, '<configure>'
    for (section, content) in settings:
        print >> output, '<%s>' % section
        for key in content:
            value = content[key]
            print >> output, '  <%s>%s</%s>' % (key, value, key)
        print >> output, '</%s>' % section
    print >> output, '</configure>'
    output.close()
# END:write

for inputName in sys.argv[1:]:
    lines = readIni(inputName)
    settings = process(lines)
    outputName = translateName(inputName)
    writeXml(outputName, settings)
