import sys

def error(msg):
    print >> sys.stderr, msg
    sys.exit(1)

def readIni(inputName):
    input = open(inputName, 'r')
    result = []
    for line in input:
        first = line.find('#')
        if first >= 0:
            line = line[:first]
        line = line.strip()
        if (not line) or (line[0] == '#'):
            continue
        result.append(line)
    return result

def escape(s):
    return s.replace('&', '&amp;')\
           .replace('<', '&lt;')\
           .replace('>', '&gt;')\
           .replace("'", '&apos;')\
           .replace('"', '&quot;')

# START:process
def process(lines):
    result = ['<configure>']
    count = 0
    for line in lines:

        # Start of new section
        if line[0] == '[':

            # Close previous section
            if count > 0:
                result.append('</section>')

            # Start new section
            title = line[1:-1]
            result.append('<section title="%s">' % title)
            count += 1

        # Entry in current section
        else:
            key, value = line.split('=', 1)
            value = escape(value)
            result.append('  <entry key="%s">%s</entry>' % \
                          (key, value))

    # Done
    if count > 0:
        result.append('</section>')
    result.append('</configure>')
    return result
# END:process

# START:rest
def translateName(inputName):
    return inputName[:-4] + '.xml'

def writeXml(outputName, settings):
    output = open(outputName, 'w')
    for line in settings:
        print >> output, line
    output.close()
# END:rest

for inputName in sys.argv[1:]:
    lines = readIni(inputName)
    settings = process(lines)
    outputName = translateName(inputName)
    writeXml(outputName, settings)
