import sys

# START:read
def error(msg):
    print >> sys.stderr, msg
    sys.exit(1)

def readIni(inputName, stack):
    input = open(inputName, 'r')
    result = []
    for line in input:

        # This part stays the same
        line = line.strip()
        first = line.find('#')
        if first >= 0:
            line = line[:first]
        if (not line) or (line[0] == '#'):
            continue

        # Regular line
        if line[0] != '%':
            result.append(line)

        # Inclusion
        else:
            filename = line[1:-1]
            if filename in stack:
                error("Recursive inclusion of %s: %s" % \
                      (filename, repr(stack)))
            newStack = stack + [filename]
            inclusion = readIni(filename, newStack)
            result = result + inclusion

    return result
# END:read

def escape(s):
    return s.replace('&', '&amp;')\
           .replace('<', '&lt;')\
           .replace('>', '&gt;')\
           .replace("'", '&apos;')\
           .replace('"', '&quot;')

def process(lines):
    result = []
    section = None
    content = {}
    for line in lines:

        # Start of new section
        if line[0] == '[':
            # Save old values (if any)
            if section:
                entry = [section, content]
                result.append(entry)

            # Start a new section
            section = line[1:-1]
            content = {}

        # Add to the current dictionary.
        else:
            key, value = line.split("=", 1)
            content[key] = escape(value)

    # Finish
    if section:
        entry = [section, content]
        result.append(entry)
    return result

def translateName(inputName):
    return inputName[:-4] + '.xml'

def writeXml(outputName, settings):
    output = open(outputName, 'w')
    print >> output, '<configure>'
    for (section, content) in settings:
        print >> output, '<%s>' % section
        for key in content:
            value = content[key]
            print >> output, '  <%s>%s</%s>' % (key, value, key)
        print >> output, '</%s>' % section
    print >> output, '</configure>'
    output.close()

for inputName in sys.argv[1:]:
    # START:call
    lines = readIni(inputName, [inputName])
    # END:call
    settings = process(lines)
    outputName = translateName(inputName)
    writeXml(outputName, settings)
