import sys

# START:readPdb
def readPdb(inputName):
    input = open(inputName, 'r')
    result = []
    for line in input:
        if line[:4] == 'ATOM':
            fields = line.split()
            atom = [fields[2]] + fields[4:7]
            result.append(atom)
    input.close()
    return result
# END:readPdb

def normalizeSymbols(atoms):
    for record in atoms:
        record[0] = record[0].capitalize()

def translateName(inputName):
    return inputName[:-4] + '.vu3'

Lookup = {
    'Br' : (1,  2, 0.9),
    'C'  : (1,  3, 0.5),
    'Cl' : (1,  8, 0.6),
    'Fe' : (1, 13, 1.1),
    'H'  : (1,  6, 0.2),
    'N'  : (1, 17, 0.5),
    'O'  : (1, 19, 0.5),
    'S'  : (1, 17, 0.7)
}

def writeVu3(outputName, atoms):
    output = open(outputName, 'w')
    for (symbol, X, Y, Z) in atoms:
        if symbol not in Lookup:
            print >> sys.stderr, 'Unknown atom "%s"' % symbol
            sys.exit(1)
        shape, color, radius = Lookup[symbol]
        print >> output, shape, color, radius, X, Y, Z
    output.close()

for inputName in sys.argv[1:]:
    atoms = readPdb(inputName)
    normalizeSymbols(atoms)
    outputName = translateName(inputName)
    writeVu3(outputName, atoms)
