import sys

# START:aux
# Print an error message and die.
def fail(msg):
    print >> sys.stderr, msg
    sys.exit(1)

# Get an argument, or fail.
def getArg(argdex, args):
    flag = args[argdex]
    if argdex >= len(args)-1:
        fail("%s requires an argument" % flag)
    return argdex+2, args[argdex+1]
# END:aux

# START:args
# Set flags.
input = []
output = None
sampling = None

# Process command-line arguments.
argdex = 1
while argdex < len(sys.argv):

    if sys.argv[argdex] in ["-n", "--number"]:
        if sampling is not None:
            fail("Sampling rate specified too many times")
        argdex, arg = getArg(argdex, sys.argv)
        try:
            sampling = int(arg)
        except ValueError:
            fail("Need integer for -n/--number, not '%s'" % arg)
        if sampling <= 0:
            fail("Sampling rate must be positive (not %d)" % sampling)

    elif sys.argv[argdex] in ["-o", "--output"]:
        if output is not None:
            fail("Too many output files specified")
        argdex, arg = getArg(argdex, sys.argv)
        try:
            output = open(arg, "w")
        except IOError:
            fail("Unable to open '%s' for output" % arg)

    elif sys.argv[argdex][0] == "-":
        fail("Unknown flag '%s'" % sys.argv[argdex])

    else:
        input.append(sys.argv[argdex])
        argdex += 1

# Check arguments, filling in defaults.
if input == []:
    input = ["-"]
if output is None:
    output = sys.stdout
if sampling is None:
    sampling = 10
# END:args

# START:main
# Process a single input file/stream.
def process(filename, output, sampling):
    if filename == "-":
        stream = sys.stdin
    else:
        try:
            stream = open(filename, "r")
        except IOError:
            fail("Unable to open '%s' for input" % filename)
    count = 0
    for line in stream:
        count += 1
        if count == sampling:
            output.write(line)
            count = 0
    stream.close()

# Process data.
for filename in input:
    process(filename, output, sampling)
output.close()
# END:main
