import sys
from xml.sax import ContentHandler, parse, ErrorHandler

class Checker(ContentHandler, ErrorHandler):

    # Construct a checker.
    def __init__(self):
        ContentHandler.__init__(self)
        self.stack = []

    # When an opening tag is seen, push its name on the stack.
    def startElement(self, name, attrs):
        self.stack.append(name)

    # When a closing tag is seen, check it, then pop the stack.
    def endElement(self, name):
        assert name == self.stack[-1]
        self.stack = self.stack[0:-1]

    # Handle exceptions during processing.
    def handleExc(self, exc):
        line = exc.getLineNumber()
        column = exc.getColumnNumber()
        msg = exc.getMessage()
        print "%s (%d %d)" % (msg, line, column)
        for tag in self.stack:
            print tag
        sys.exit(1)

    # Redirect warnings, errors, and fatal errors to handleExc.
    warning = handleExc
    error = handleExc
    fatalError = handleExc

# Run the program from the command line.
if __name__ == "__main__":
    handler = Checker()
    parse(sys.stdin, handler, handler)
