import sys
from xml.sax import ContentHandler, parse, ErrorHandler

class Normalizer(ContentHandler):

    # Construct a normalizer.
    def __init__(self, stream):
        self.stream = stream
        self.pending = None

    # Record the details of an opening tag.
    def startElement(self, name, attrs):
        self.makePending(name, attrs)

    # Handle a closing tag by closing the short form opening tag,
    # or by writing out the closing tag on its own.
    def endElement(self, name):
        if self.pending:
            self.stream.write(self.pending + "/>")
        else:
            self.stream.write("</" + name + ">")
        self.pending = None

    # On text and ignorable whitespace, write any pending opening
    # tags using the normal form.
    def characters(self, text):
        self.clearPending(text)

    def ignorableWhitespace(self, text):
        self.clearPending(text)

    # Record enough about an opening tag to reproduce it.
    def makePending(self, name, attrs):
        self.clearPending()
        self.pending = "<" + name
        keys = attrs.keys()
        keys.sort()
        for k in keys:
            self.pending += ' %s="%s"' % (k, attrs[k])

    # Clear the pending opening tag if intervening text is seen.
    def clearPending(self, text=""):
        if self.pending:
            self.stream.write(self.pending + ">")
            self.pending = None
        self.stream.write(text)

# Run the program from the command line.
if __name__ == "__main__":
    handler = Normalizer(sys.stdout)
    parse(sys.stdin, handler, handler)
