/***
 * Excerpted from "Data Crunching"
 * We make no guarantees that this code is fit for any purpose. 
 * Visit http://www.pragmaticprogrammer.com/titles/gwd for more book information.
***/
import java.util.Iterator;
import java.io.PrintStream;
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.Text;
import org.jdom.input.SAXBuilder;

// START:class
public class TracingVisitor extends DomVisitor {

    public static void main(String[] args) {
        try {
            SAXBuilder builder = new SAXBuilder();
            Document doc = builder.build(args[0]);
            TracingVisitor tracer = 
                new TracingVisitor(System.out);
            tracer.visit(doc.getRootElement());
        }
        catch (Exception e) {
            System.err.println(e);
        }
    }

    public TracingVisitor(PrintStream out) {
        _out = out;
    }

    protected void preRoot(Element root) {
        _out.println(indent() + "preRoot");
    }

    protected void postRoot(Element root) {
        _out.println(indent() + "postRoot");
    }

    protected void atElement(Element elt) {
        _out.println(indent() + "atElement " + elt.getName());
    }

    protected void atText(Text text) {
        _out.println(indent() + "atText " + 
                     text.getText().length() + 
                     " characters");
    }

    protected String indent() {
        String result = "";
        for (int i=0; i<_depth; ++i) {
            result += " ";
        }
        return result;
    }

    protected PrintStream _out;
}
// END:class
